# -*- coding: UTF-8 -*-
from generic_links.models import GenericLink


def get_links_for(obj, is_external=None):
    """
    Returns a queryset with all instances of GenericLink for a given object
    """

    params = dict(object_id=obj.id, content_type__app_label=obj._meta.app_label,
        content_type__model=obj._meta.module_name)

    if not (is_external is None):
        params["is_external"] = is_external

    return GenericLink.objects.filter(**params)



# -*- coding: utf-8 -*-
from django.http import Http404
from django.shortcuts import render_to_response, HttpResponseRedirect
from django.template import RequestContext

from generic_links.forms import AddLinkForm


def add_link(request, app_model, object_id):

    app, model = app_model.split(".")
    Model = get_model(app, model)

    try:
        an_object = Model.objects.get(pk=object_id)
    except Model.DoesNotExist:
        raise Http404

    if request.method == "POST":
        form = AddForm(request.user, content_type, object_id, data=request.POST)
        if form.is_valid():
            link = form.save()
            return HttpResponseRedirect(request.META.get("HTTP_REFERER"))
    else:
        form = AddForm(request.user, content_type, object_id)

    return render_to_response("generic_links/links/add.html",
        {"object": object, "app_model": app_model, "form": form},
        context_instance=RequestContext(request))



# -*- coding: utf-8 -*-
"""
Several usefull template tags!
"""
from django import template

from generic_links import utils


register = template.Library()


class RelatedLinksNode(template.Node):

    def __init__(self, context_var, obj):
        self.context_var = context_var
        self.obj_var = template.Variable(obj)

    def render(self, context):
        obj = self.obj_var.resolve(context)
        context[self.context_var] = utils.get_links_for(obj).select_related("user")
        return u""


@register.tag
def get_links_for(parser, token):
    """
    Usage: {% get_links_for <obj> as <some_var> %}
    """

    bits = token.split_contents()

    if len(bits) != 4:
        message = "'%s' tag requires three arguments" % bits[0]
        raise template.TemplateSyntaxError(message)

    return RelatedLinksNode(bits[3], bits[1])

"""
Usage: {% get_links_for <obj> owned by <user> as <some_var> %}
Usage: {% get_external_links_for <obj> owned by <user> as <some_var> %}
"""



# -*- coding: utf-8 -*-
from django.conf.urls.defaults import patterns, url


urlpatterns = patterns('generic_links.views',
    url(r'^(?P<app_model>.*?)/(?P<object_id>\d+)/links/add/$',
        "add_link", name="generic_links_add_link"),
)




# -*- coding: UTF-8 -*-
from setuptools import setup
from generic_links import get_version


setup(
    name='django-generic-links',
    version=get_version(),
    license='BSD License Version 2',
    description='Simple and generic application for Django projects to attach and handle links for any object',
    long_description=('It provides a model, admin model and templatetags to attach links to any model instance and retrive and handle them.'),
    keywords='django apps links generic',
    author='Matías Agustín Méndez',
    author_email='matagus@gmail.com',
    url='http://matagus.github.com/django-generic-links/',
    packages=['generic_links', 'generic_links.templatetags', ],
    tests_require=['django>=1.2,<1.5', ],
    test_suite='runtests.runtests',
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        'Environment :: Plugins',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        "Programming Language :: Python :: 2.5",
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)



# -*- coding: utf-8 -*-
from django.contrib import admin
from django.contrib.contenttypes import generic

from generic_links.models import GenericLink


class GenericLinkStackedInline(generic.GenericStackedInline):
    model = GenericLink
    extra = 1


class GenericLinkTabularInline(generic.GenericTabularInline):
    model = GenericLink
    extra = 1


class GenericLinkAdmin(admin.ModelAdmin):
    list_display = ("title", "url", "description", "created_at", "user", "is_external")
    search_fields = ('title', 'url', 'user')
    list_filter = ('is_external', 'created_at', )
    # hoping you have a lot of users
    raw_id_fields = ('user', )


admin.site.register(GenericLink, GenericLinkAdmin)
